.. _all-salt.pillars:

==============
pillar modules
==============

.. currentmodule:: salt.pillar

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    cmd_json
    cmd_yaml
    extra_minion_data_in_pillar
    file_tree
    git_pillar
    gpg
    nodegroups
    postgres
    sql_base
